searchNodes=[{"doc":"Req plugin to instrument requests with :telemetry events. Usage Preferably, ReqTelemetry should be the last plugin attached to your %Req.Request{} . This allows ReqTelemetry to emit events both at the very start and very end of the request and response pipelines. In this way, you can observe both the total time spent issuing and processing the request and response, as well as the time spent only with the request adapter. req = Req . new ( ) |&gt; ReqTelemetry . attach ( ) req = Req . new ( adapter : &amp; my_adapter / 1 ) |&gt; ReqSomeOtherThing . attach ( ) |&gt; ReqTelemetry . attach ( ) Events ReqTelemetry produces the following events (in order of event dispatch): [:req, :request, :pipeline, :start] [:req, :request, :adapter, :start] [:req, :request, :adapter, :stop] [:req, :request, :adapter, :error] [:req, :request, :pipeline, :stop] [:req, :request, :pipeline, :error] You can configure ReqTelemetry to produce only :pipeline or :adapter events; see ReqTelemetry.attach/2 for options. Logging ReqTelemetry defines a a simple, default logger that logs basic request information and timing. Here's how a successful request might be logged: Req : 479128347 - GET https :// example . org ( pipeline ) Req : 479128347 - GET https :// example . org ( adapter ) Req : 479128347 - 200 in 403 ms ( adapter ) Req : 479128347 - 200 in 413 ms ( pipeline ) For usage and configuration, see ReqTelemetry.attach_default_logger/1 .","ref":"ReqTelemetry.html","title":"ReqTelemetry","type":"module"},{"doc":"Installs request, response, and error steps that emit :telemetry events. Options All events are emitted by default, but can be limited using the following options: false - do not emit telemetry events [pipeline: false] - do not emit pipeline telemetry events [adapter: false] - do not emit adapter telemetry events These same options can also be passed through Req options under the :telemetry key to change the behavior on a per-request basis. Examples Emit all events by default, limiting them per-request as needed. req = Req . new ( ) |&gt; ReqTelemetry . attach ( ) # Emits all events Req . get! ( req , url : &quot;https://example.org&quot; ) # Do not emit events Req . get! ( req , url : &quot;https://example.org&quot; , telemetry : false ) # Emit adapter events but not pipeline events Req . get! ( req , url : &quot;https://example.org&quot; , telemetry : [ pipeline : false ] ) Suppress all events by default, enabling them per-request as needed. req = Req . new ( ) |&gt; ReqTelemetry . attach ( false ) # Will not emit events Req . get! ( req , url : &quot;https://example.org&quot; ) # Override to emit events Req . get! ( req , url : &quot;https://example.org&quot; , telemetry : true ) # Override to emit only adapter events Req . get! ( req , url : &quot;https://example.org&quot; , telemetry : [ adapter : true ] ) Finally, suppress only a certain kind of event by default, overriding that default as needed. req = Req . new ( ) |&gt; ReqTelemetry . attach ( pipeline : false ) # Will only emit adapter events Req . get! ( req , url : &quot;https://example.org&quot; ) # Override to emit only pipeline events Req . get! ( req , url : &quot;https://example.org&quot; , telemetry : [ pipeline : true , adapter : false ] )","ref":"ReqTelemetry.html#attach/2","title":"ReqTelemetry.attach/2","type":"function"},{"doc":"Attach a basic telemetry event handler that logs ReqTelemetry events. Usage Telemetry event handlers can be attached in your application's start/2 callback: @impl true def start ( _type , _args ) do ReqTelemetry . attach_default_logger ( ) children = [ ... ] Supervisor . start_link ( ... ) end All events are logged by default, but this can be overriden by passing in a keyword describing the kind of events to log or a list of specific events to log. # Logs all events :ok = ReqTelemetry . attach_default_logger ( ) # Logs only adapter events :ok = ReqTelemetry . attach_default_logger ( :adapter ) # Logs only pipeline errors :ok = ReqTelemetry . attach_default_logger ( [ [ :req , :request , :pipeline , :error ] ] ) Example Here's what a successful request might look like: 15 : 52 : 01.462 [ info ] Req : 479128347 - GET https :// example . org ( pipeline ) 15 : 52 : 01.466 [ info ] Req : 479128347 - GET https :// example . org ( adapter ) 15 : 52 : 01.869 [ info ] Req : 479128347 - 200 in 403 ms ( adapter ) 15 : 52 : 01.875 [ info ] Req : 479128347 - 200 in 413 ms ( pipeline ) And here's what an error might look like: 15 : 52 : 04.174 [ error ] Req : 42446822 - ERROR in 2012 ms ( adapter ) % Finch.Error { reason : :request_timeout }","ref":"ReqTelemetry.html#attach_default_logger/1","title":"ReqTelemetry.attach_default_logger/1","type":"function"},{"doc":"Returns a list of events emitted by ReqTelemetry .","ref":"ReqTelemetry.html#events/1","title":"ReqTelemetry.events/1","type":"function"},{"doc":"","ref":"ReqTelemetry.html#t:option/0","title":"ReqTelemetry.option/0","type":"type"},{"doc":"","ref":"ReqTelemetry.html#t:options/0","title":"ReqTelemetry.options/0","type":"type"},{"doc":"Req plugin to instrument requests with :telemetry events.","ref":"readme.html","title":"ReqTelemetry","type":"extras"},{"doc":"Preferably, ReqTelemetry should be the last plugin attached to your %Req.Request{} . This allows ReqTelemetry to emit events both at the very start and very end of the request and response pipelines. In this way, you can observe both the total time spent issuing and processing the request and response, as well as the time spent only with the request adapter. req = Req . new ( ) |&gt; ReqTelemetry . attach ( ) req = Req . new ( adapter : &amp; my_adapter / 1 ) |&gt; ReqSomeOtherThing . attach ( ) |&gt; ReqTelemetry . attach ( )","ref":"readme.html#usage","title":"ReqTelemetry - Usage","type":"extras"},{"doc":"ReqTelemetry produces the following events (in order of event dispatch): [:req, :request, :pipeline, :start] [:req, :request, :adapter, :start] [:req, :request, :adapter, :stop] [:req, :request, :adapter, :error] [:req, :request, :pipeline, :stop] [:req, :request, :pipeline, :error] You can configure ReqTelemetry to produce only :pipeline or :adapter events; see ReqTelemetry.attach/2 for options.","ref":"readme.html#events","title":"ReqTelemetry - Events","type":"extras"},{"doc":"ReqTelemetry defines a a simple, default logger that logs basic request information and timing. Here's how a successful request might be logged: Req : 479128347 - GET https :// example . org ( pipeline ) Req : 479128347 - GET https :// example . org ( adapter ) Req : 479128347 - 200 in 403 ms ( adapter ) Req : 479128347 - 200 in 413 ms ( pipeline ) For usage and configuration, see ReqTelemetry.attach_default_logger/1 .","ref":"readme.html#logging","title":"ReqTelemetry - Logging","type":"extras"},{"doc":"req_telemetry is not yet available through Hex. In the meantime, you can install it by adding the repository directly: def deps do [ { :req_telemetry , github : &quot;zachallaun/req_telemetry&quot; } ] end","ref":"readme.html#installation","title":"ReqTelemetry - Installation","type":"extras"}]